## Aliyun ROS ELASTICSEARCHSERVERLESS Construct Library

This module is part of the AliCloud ROS Cloud Development Kit (ROS CDK) project.

```python
import * as ELASTICSEARCHSERVERLESS from '@alicloud/ros-cdk-elasticsearchserverless';
```
